@@ -8,7 +8,7 @@ use strict;
 
 package XML::Compile;
 use vars '$VERSION';
-$VERSION = '0.79';
+$VERSION = '0.80';
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
 use XML::LibXML;
@@ -136,7 +136,7 @@ sub _parsedNode($)
 {   my ($thing, $node) = @_;
 
     if($node->isa('XML::LibXML::Document'))
-    {   my $eltype = type_of_node $node->documentElement;
+    {   my $eltype = type_of_node($node->documentElement) || '(none)';
         trace "using preparsed XML document with element <$eltype>";
     }
     elsif($node->isa('XML::LibXML::Element'))
