@@ -5,7 +5,7 @@
 
 package XML::Compile::Schema::Template;
 use vars '$VERSION';
-$VERSION = '0.79';
+$VERSION = '0.80';
 
 use XML::Compile::Schema::XmlWriter;
 
@@ -23,6 +23,11 @@ BEGIN {
       for qw/tag_qualified tag_unqualified wrapper_ns/;
 }
 
+sub typemap_to_hooks($$)
+{   my ($hooks, $typemap) = @_;
+    $hooks;
+}
+
 sub element_wrapper
 {   my ($path, $args, $processor) = @_;
     sub { $processor->() };
